@@ -16,7 +16,7 @@ class ESDocument(BaseModel):
     issued: Optional[str]
     periodicity: Optional[str] = ""
     provenance: Optional[str] = "NAV"
-    contactPoint: Optional[str] = ""
+    contactpoint: Optional[str] = {}
     author: Optional[str] = ""
     repo: Optional[str] = ""
     readme: Optional[str] = ""
